summaryrefslogtreecommitdiffstats
path: root/src/gui/itemselector.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/itemselector.h')
-rw-r--r--src/gui/itemselector.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/gui/itemselector.h b/src/gui/itemselector.h
index 28f31b2..d0fd691 100644
--- a/src/gui/itemselector.h
+++ b/src/gui/itemselector.h
@@ -27,8 +27,8 @@ namespace KateMDI { class ToolView; }
class ILVItem : public TQObject, public KListViewItem
{
public:
- ILVItem( TQListView *tqparent, const TQString &id );
- ILVItem( TQListViewItem *tqparent, const TQString &id );
+ ILVItem( TQListView *parent, const TQString &id );
+ ILVItem( TQListViewItem *parent, const TQString &id );
void setProjectItem( ProjectItem * projectItem ) { m_pProjectItem = projectItem; }
ProjectItem * projectItem() const { return m_pProjectItem; }
@@ -60,7 +60,7 @@ class ItemSelector : public KListView
Q_OBJECT
TQ_OBJECT
public:
- ItemSelector( TQWidget *tqparent, const char *name );
+ ItemSelector( TQWidget *parent, const char *name );
~ItemSelector();
/**
* Adds a listview item to the ListView
@@ -91,7 +91,7 @@ class ItemSelector : public KListView
*/
void setListCaption( const TQString &caption );
/**
* Writes the open status (folded or unfolded) of "tqparent" items in the view
* to the config file.
*/
void writeOpenStates();
@@ -124,11 +124,11 @@ class ComponentSelector : public ItemSelector
Q_OBJECT
TQ_OBJECT
public:
- static ComponentSelector * self( KateMDI::ToolView * tqparent = 0l );
+ static ComponentSelector * self( KateMDI::ToolView * parent = 0l );
static TQString toolViewIdentifier() { return "ComponentSelector"; }
private:
- ComponentSelector( KateMDI::ToolView * tqparent );
+ ComponentSelector( KateMDI::ToolView * parent );
static ComponentSelector * m_pSelf;
};
@@ -142,11 +142,11 @@ class FlowPartSelector : public ItemSelector
Q_OBJECT
TQ_OBJECT
public:
- static FlowPartSelector * self( KateMDI::ToolView * tqparent = 0l );
+ static FlowPartSelector * self( KateMDI::ToolView * parent = 0l );
static TQString toolViewIdentifier() { return "FlowPartSelector"; }
private:
- FlowPartSelector( KateMDI::ToolView * tqparent );
+ FlowPartSelector( KateMDI::ToolView * parent );
static FlowPartSelector * m_pSelf;
};
@@ -159,11 +159,11 @@ class MechanicsSelector : public ItemSelector
Q_OBJECT
TQ_OBJECT
public:
- static MechanicsSelector * self( KateMDI::ToolView * tqparent = 0l );
+ static MechanicsSelector * self( KateMDI::ToolView * parent = 0l );
static TQString toolViewIdentifier() { return "MechanicsSelector"; }
private:
- MechanicsSelector( TQWidget *tqparent = 0L );
+ MechanicsSelector( TQWidget *parent = 0L );
static MechanicsSelector * m_pSelf;
};
@@ -91,7 +91,7 @@ class ItemSelector : public KListView
void setListCaption( const TQString &caption );
/**
- * Writes the open status (folded or unfolded) of "tqparent" items in the view
+ * Writes the open status (folded or unfolded) of "parent" items in the view
* to the config file.
*/